@@ -382,24 +382,21 @@ class Viewer(object, metaclass=Singleton):
                 status_text, status_symbol, self.text_column_1, self.text_column_2
             ))
 
-        sys.stdout.write(" " * shutil.get_terminal_size()[0])
-        sys.stdout.write("\b" * shutil.get_terminal_size()[0])
+        # sys.stdout.write(" " * shutil.get_terminal_size()[0])
+        # sys.stdout.write("\b" * shutil.get_terminal_size()[0])
+        sys.stdout.write('\33[1K')
         sys.stdout.write(string_print)
 
         if prompt is None:
             sys.stdout.write("\n")
-
-        elif int(prompt) < 0:
-            # sys.stdout.write("\b" * self.size_line_actual)
-            sys.stdout.write("\b" * int(shutil.get_terminal_size()[0] - len(string_print)))
-            if with_date:
-                sys.stdout.write("\b" * self.size_line_actual)
-            else:
-                sys.stdout.write("\b" * int(len(string_print) - self.size_line_actual))
-        else:
-            sys.stdout.write("\b" * shutil.get_terminal_size()[0])
-
-            # sys.stdout.write("\b" * shutil.get_terminal_size()[0])
+        sys.stdout.write('\33[1K')
+        # elif int(prompt) < 0:
+        #     if with_date:
+        #         sys.stdout.write("\b" * int(len(string_print) - self.size_line_actual - 13))
+        #     else:
+        #         sys.stdout.write("\b" * int(len(string_print) - self.size_line_actual + 1))
+        # else:
+        #     sys.stdout.write("\b" * shutil.get_terminal_size()[0])
 
         # Only on final flush, that because that ultra slow
         self.size_line_previous = len(string_print)
